==> eiffelstudio-18.11.10.2592.tar: F_code/C9/st430.c <==
/*
 * Code for class ST_UNICODE_CASE_MAPPING_INTERFACE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "st430.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ST_UNICODE_CASE_MAPPING_INTERFACE}.lower_utf8_string */
EIF_REFERENCE F1116_8126 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(8);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLR(3,loc4);
	RTLR(4,Current);
	RTLR(5,tr2);
	RTLR(6,tr3);
	RTLR(7,tr4);
	RTLIU(8);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
	tr1 = RTLNS(eif_new_type(2139, 0x00).id, 2139, _OBJSIZ_1_1_0_6_0_0_0_0_);
	F2139_22028(RTCW(tr1), loc2);
	Result = (EIF_REFERENCE) tr1;
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		loc3 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R5070[Dtype(arg1)-1086])(RTCW(arg1), loc1);
		loc4 = F1116_8128(Current, loc3);
		if ((EIF_BOOLEAN)(loc4 != NULL)) {
			{
				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1000,2139,0xFFFF};
				EIF_TYPE typres0;
				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
				
				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
				tr1 = RTLNTS(typres0.id, 2, 0);
			}
			((EIF_TYPED_VALUE *)tr1+1)->it_r = Result;
			RTAR(tr1,Result);
			
			{
				static EIF_TYPE_INDEX typarr0[] = {1074,0xFFF9,1,1000,1006,0xFFFF};
				EIF_TYPE typres0;
				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
				
				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
				tr4 = RTLNRF(typres0.id, (EIF_POINTER) __A1268_283_2, (EIF_POINTER) _A1268_283_2, (EIF_POINTER)(F2139_22083),tr1, 1, 1);
			}
			F1413_11618(RTCW(loc4), tr4);
		} else {
			F2139_22083(RTCW(Result), loc3);
		}
		loc1++;
	}
	RTLE;
	return Result;
}

/* {ST_UNICODE_CASE_MAPPING_INTERFACE}.upper_utf8_string */
EIF_REFERENCE F1116_8127 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(8);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLR(3,loc4);
	RTLR(4,Current);
	RTLR(5,tr2);
	RTLR(6,tr3);
	RTLR(7,tr4);
	RTLIU(8);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
	tr1 = RTLNS(eif_new_type(2139, 0x00).id, 2139, _OBJSIZ_1_1_0_6_0_0_0_0_);
	F2139_22028(RTCW(tr1), loc2);
	Result = (EIF_REFERENCE) tr1;
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		loc3 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R5070[Dtype(arg1)-1086])(RTCW(arg1), loc1);
		loc4 = F1116_8129(Current, loc3);
		if ((EIF_BOOLEAN)(loc4 != NULL)) {
			{
				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1000,2139,0xFFFF};
				EIF_TYPE typres0;
				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
				
				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
				tr1 = RTLNTS(typres0.id, 2, 0);
			}
			((EIF_TYPED_VALUE *)tr1+1)->it_r = Result;
			RTAR(tr1,Result);
			
			{
				static EIF_TYPE_INDEX typarr0[] = {1074,0xFFF9,1,1000,1006,0xFFFF};
				EIF_TYPE typres0;
				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
				
				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
				tr4 = RTLNRF(typres0.id, (EIF_POINTER) __A1268_283_2, (EIF_POINTER) _A1268_283_2, (EIF_POINTER)(F2139_22083),tr1, 1, 1);
			}
			F1413_11618(RTCW(loc4), tr4);
		} else {
			F2139_22083(RTCW(Result), loc3);
		}
		loc1++;
	}
	RTLE;
	return Result;
}

/* {ST_UNICODE_CASE_MAPPING_INTERFACE}.lower_codes */
EIF_REFERENCE F1116_8128 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 65536L));
	loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 65536L));
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 / ((EIF_INTEGER_32) 256L));
	loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 256L));
	Result = RTOSCF(8158,F1117_8158,(Current));
	/* INLINED CODE (SPECIAL.item) */
	tr2 = *((EIF_REFERENCE *)RTCW(Result) + (loc1));
	/* END INLINED CODE */
	Result = tr2;
	/* INLINED CODE (SPECIAL.item) */
	tr2 = *((EIF_REFERENCE *)RTCW(Result) + (loc2));
	/* END INLINED CODE */
	Result = tr2;
	Result = F840_4216(RTCW(Result), loc3);
	RTLE;
	return Result;
}

/* {ST_UNICODE_CASE_MAPPING_INTERFACE}.upper_codes */
EIF_REFERENCE F1116_8129 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 65536L));
	loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 65536L));
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 / ((EIF_INTEGER_32) 256L));
	loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 256L));
	Result = RTOSCF(8204,F1117_8204,(Current));
	/* INLINED CODE (SPECIAL.item) */
	tr2 = *((EIF_REFERENCE *)RTCW(Result) + (loc1));
	/* END INLINED CODE */
	Result = tr2;
	/* INLINED CODE (SPECIAL.item) */
	tr2 = *((EIF_REFERENCE *)RTCW(Result) + (loc2));
	/* END INLINED CODE */
	Result = tr2;
	Result = F840_4216(RTCW(Result), loc3);
	RTLE;
	return Result;
}

/* {ST_UNICODE_CASE_MAPPING_INTERFACE}.new_singleton */
EIF_REFERENCE F1116_8134 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {1442,1006,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1442, _OBJSIZ_4_0_0_2_0_0_0_0_);
	}
	F1443_11892(RTCW(tr1), ((EIF_INTEGER_32) 1L));
	Result = (EIF_REFERENCE) tr1;
	F1443_11911(RTCW(Result), arg1);
	RTLE;
	return Result;
}

/* {ST_UNICODE_CASE_MAPPING_INTERFACE}.new_pair */
EIF_REFERENCE F1116_8135 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {1442,1006,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1442, _OBJSIZ_4_0_0_2_0_0_0_0_);
	}
	F1443_11892(RTCW(tr1), ((EIF_INTEGER_32) 2L));
	Result = (EIF_REFERENCE) tr1;
	F1443_11911(RTCW(Result), arg1);
	F1443_11911(RTCW(Result), arg2);
	RTLE;
	return Result;
}

/* {ST_UNICODE_CASE_MAPPING_INTERFACE}.new_triple */
EIF_REFERENCE F1116_8136 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {1442,1006,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1442, _OBJSIZ_4_0_0_2_0_0_0_0_);
	}
	F1443_11892(RTCW(tr1), ((EIF_INTEGER_32) 3L));
	Result = (EIF_REFERENCE) tr1;
	F1443_11911(RTCW(Result), arg1);
	F1443_11911(RTCW(Result), arg2);
	F1443_11911(RTCW(Result), arg3);
	RTLE;
	return Result;
}

void EIF_Minit430 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C9/st430.c <==
/*
 * Code for class ST_UNICODE_CASE_MAPPING_INTERFACE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "st430.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ST_UNICODE_CASE_MAPPING_INTERFACE}.lower_utf8_string */
EIF_REFERENCE F1116_8157 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(8);
	RTLR(0,arg1);
	RTLR(1,Result);
	RTLR(2,loc4);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLR(5,tr2);
	RTLR(6,tr3);
	RTLR(7,tr4);
	RTLIU(8);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
	Result = RTLNS(eif_new_type(2146, 0x01).id, 2146, _OBJSIZ_1_1_0_6_0_0_0_0_);
	F2146_22075(RTCW(Result), loc2);
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		loc3 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R5091[Dtype(RTCW(arg1))-1086])(arg1, loc1);
		loc4 = F1116_8159(Current, loc3);
		if ((EIF_BOOLEAN)(loc4 != NULL)) {
			{
				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1000,0xFF01,2146,0xFFFF};
				EIF_TYPE typres0;
				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
				
				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
				tr1 = RTLNTS(typres0.id, 2, 0);
			}
			((EIF_TYPED_VALUE *)tr1+1)->it_r = Result;
			RTAR(tr1,Result);
			
			{
				static EIF_TYPE_INDEX typarr0[] = {0xFF01,1074,0xFF01,0xFFF9,1,1000,1009,0xFFFF};
				EIF_TYPE typres0;
				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
				
				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A1269_283_2, (EIF_POINTER) _A1269_283_2, (EIF_POINTER)(F2146_22130),tr1, 1, 1);
			}
			F1419_11651(RTCW(loc4), tr4);
		} else {
			F2146_22130(RTCW(Result), loc3);
		}
		loc1++;
	}
	RTLE;
	return Result;
}

/* {ST_UNICODE_CASE_MAPPING_INTERFACE}.upper_utf8_string */
EIF_REFERENCE F1116_8158 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(8);
	RTLR(0,arg1);
	RTLR(1,Result);
	RTLR(2,loc4);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLR(5,tr2);
	RTLR(6,tr3);
	RTLR(7,tr4);
	RTLIU(8);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
	Result = RTLNS(eif_new_type(2146, 0x01).id, 2146, _OBJSIZ_1_1_0_6_0_0_0_0_);
	F2146_22075(RTCW(Result), loc2);
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		loc3 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R5091[Dtype(RTCW(arg1))-1086])(arg1, loc1);
		loc4 = F1116_8160(Current, loc3);
		if ((EIF_BOOLEAN)(loc4 != NULL)) {
			{
				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1000,0xFF01,2146,0xFFFF};
				EIF_TYPE typres0;
				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
				
				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
				tr1 = RTLNTS(typres0.id, 2, 0);
			}
			((EIF_TYPED_VALUE *)tr1+1)->it_r = Result;
			RTAR(tr1,Result);
			
			{
				static EIF_TYPE_INDEX typarr0[] = {0xFF01,1074,0xFF01,0xFFF9,1,1000,1009,0xFFFF};
				EIF_TYPE typres0;
				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
				
				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A1269_283_2, (EIF_POINTER) _A1269_283_2, (EIF_POINTER)(F2146_22130),tr1, 1, 1);
			}
			F1419_11651(RTCW(loc4), tr4);
		} else {
			F2146_22130(RTCW(Result), loc3);
		}
		loc1++;
	}
	RTLE;
	return Result;
}

/* {ST_UNICODE_CASE_MAPPING_INTERFACE}.lower_codes */
EIF_REFERENCE F1116_8159 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 65536L));
	loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 65536L));
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 / ((EIF_INTEGER_32) 256L));
	loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 256L));
	Result = RTOSCF(8189,F1117_8189, (Current));
	/* INLINED CODE (SPECIAL.item) */
	tr2 = *((EIF_REFERENCE *)RTCW(Result) + (loc1));
	/* END INLINED CODE */
	Result = tr2;
	/* INLINED CODE (SPECIAL.item) */
	tr2 = *((EIF_REFERENCE *)RTCW(Result) + (loc2));
	/* END INLINED CODE */
	Result = tr2;
	Result = F840_4232(RTCW(Result), loc3);
	RTLE;
	return Result;
}

/* {ST_UNICODE_CASE_MAPPING_INTERFACE}.upper_codes */
EIF_REFERENCE F1116_8160 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 / ((EIF_INTEGER_32) 65536L));
	loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 65536L));
	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 / ((EIF_INTEGER_32) 256L));
	loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 % ((EIF_INTEGER_32) 256L));
	Result = RTOSCF(8235,F1117_8235, (Current));
	/* INLINED CODE (SPECIAL.item) */
	tr2 = *((EIF_REFERENCE *)RTCW(Result) + (loc1));
	/* END INLINED CODE */
	Result = tr2;
	/* INLINED CODE (SPECIAL.item) */
	tr2 = *((EIF_REFERENCE *)RTCW(Result) + (loc2));
	/* END INLINED CODE */
	Result = tr2;
	Result = F840_4232(RTCW(Result), loc3);
	RTLE;
	return Result;
}

/* {ST_UNICODE_CASE_MAPPING_INTERFACE}.new_singleton */
EIF_REFERENCE F1116_8165 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,1447,1009,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		Result = RTLNS(typres0.id, 1447, _OBJSIZ_4_0_0_2_0_0_0_0_);
	}
	F1448_11925(RTCW(Result), ((EIF_INTEGER_32) 1L));
	F1448_11944(RTCW(Result), arg1);
	RTLE;
	return Result;
}

/* {ST_UNICODE_CASE_MAPPING_INTERFACE}.new_pair */
EIF_REFERENCE F1116_8166 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,1447,1009,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		Result = RTLNS(typres0.id, 1447, _OBJSIZ_4_0_0_2_0_0_0_0_);
	}
	F1448_11925(RTCW(Result), ((EIF_INTEGER_32) 2L));
	F1448_11944(RTCW(Result), arg1);
	F1448_11944(RTCW(Result), arg2);
	RTLE;
	return Result;
}

/* {ST_UNICODE_CASE_MAPPING_INTERFACE}.new_triple */
EIF_REFERENCE F1116_8167 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,1447,1009,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		Result = RTLNS(typres0.id, 1447, _OBJSIZ_4_0_0_2_0_0_0_0_);
	}
	F1448_11925(RTCW(Result), ((EIF_INTEGER_32) 3L));
	F1448_11944(RTCW(Result), arg1);
	F1448_11944(RTCW(Result), arg2);
	F1448_11944(RTCW(Result), arg3);
	RTLE;
	return Result;
}

void EIF_Minit430 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
